summaryrefslogtreecommitdiffstats
path: root/src/libs/engine/events
diff options
context:
space:
mode:
Diffstat (limited to 'src/libs/engine/events')
-rw-r--r--src/libs/engine/events/CreateNodeEvent.cpp1
-rw-r--r--src/libs/engine/events/CreatePatchEvent.cpp5
-rw-r--r--src/libs/engine/events/CreatePortEvent.cpp1
-rw-r--r--src/libs/engine/events/DestroyEvent.cpp5
-rw-r--r--src/libs/engine/events/DestroyEvent.hpp4
-rw-r--r--src/libs/engine/events/RenameEvent.cpp5
-rw-r--r--src/libs/engine/events/RenameEvent.hpp4
-rw-r--r--src/libs/engine/events/RequestMetadataEvent.cpp2
-rw-r--r--src/libs/engine/events/RequestMetadataEvent.hpp4
-rw-r--r--src/libs/engine/events/RequestObjectEvent.hpp6
-rw-r--r--src/libs/engine/events/SetMetadataEvent.cpp2
-rw-r--r--src/libs/engine/events/SetMetadataEvent.hpp6
-rw-r--r--src/libs/engine/events/SetPolyphonicEvent.hpp8
13 files changed, 24 insertions, 29 deletions
diff --git a/src/libs/engine/events/CreateNodeEvent.cpp b/src/libs/engine/events/CreateNodeEvent.cpp
index 65296de6..6ed860dd 100644
--- a/src/libs/engine/events/CreateNodeEvent.cpp
+++ b/src/libs/engine/events/CreateNodeEvent.cpp
@@ -22,7 +22,6 @@
#include "Responder.hpp"
#include "Patch.hpp"
#include "Node.hpp"
-#include "Tree.hpp"
#include "Plugin.hpp"
#include "Engine.hpp"
#include "Patch.hpp"
diff --git a/src/libs/engine/events/CreatePatchEvent.cpp b/src/libs/engine/events/CreatePatchEvent.cpp
index 288eaee3..748d44dc 100644
--- a/src/libs/engine/events/CreatePatchEvent.cpp
+++ b/src/libs/engine/events/CreatePatchEvent.cpp
@@ -15,17 +15,16 @@
* 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
+#include <raul/Maid.hpp>
+#include <raul/Path.hpp>
#include "CreatePatchEvent.hpp"
#include "Responder.hpp"
#include "Patch.hpp"
#include "Node.hpp"
-#include "Tree.hpp"
#include "Plugin.hpp"
#include "Engine.hpp"
-#include <raul/Maid.hpp>
#include "ClientBroadcaster.hpp"
#include "AudioDriver.hpp"
-#include <raul/Path.hpp>
#include "ObjectStore.hpp"
namespace Ingen {
diff --git a/src/libs/engine/events/CreatePortEvent.cpp b/src/libs/engine/events/CreatePortEvent.cpp
index b8bc75e6..6163d4ab 100644
--- a/src/libs/engine/events/CreatePortEvent.cpp
+++ b/src/libs/engine/events/CreatePortEvent.cpp
@@ -22,7 +22,6 @@
#include "Responder.hpp"
#include "CreatePortEvent.hpp"
#include "Patch.hpp"
-#include "Tree.hpp"
#include "Plugin.hpp"
#include "Engine.hpp"
#include "Patch.hpp"
diff --git a/src/libs/engine/events/DestroyEvent.cpp b/src/libs/engine/events/DestroyEvent.cpp
index a3d96ede..2ccad693 100644
--- a/src/libs/engine/events/DestroyEvent.cpp
+++ b/src/libs/engine/events/DestroyEvent.cpp
@@ -15,11 +15,12 @@
* 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
+#include <raul/Maid.hpp>
+#include <raul/Path.hpp>
#include "DestroyEvent.hpp"
#include "Responder.hpp"
#include "Engine.hpp"
#include "Patch.hpp"
-#include "Tree.hpp"
#include "NodeBase.hpp"
#include "Plugin.hpp"
#include "AudioDriver.hpp"
@@ -27,9 +28,7 @@
#include "DisconnectNodeEvent.hpp"
#include "DisconnectPortEvent.hpp"
#include "ClientBroadcaster.hpp"
-#include <raul/Maid.hpp>
#include "ObjectStore.hpp"
-#include <raul/Path.hpp>
#include "QueuedEventSource.hpp"
#include "Port.hpp"
diff --git a/src/libs/engine/events/DestroyEvent.hpp b/src/libs/engine/events/DestroyEvent.hpp
index 5ab3b01f..77167598 100644
--- a/src/libs/engine/events/DestroyEvent.hpp
+++ b/src/libs/engine/events/DestroyEvent.hpp
@@ -33,7 +33,7 @@ template<typename T> class TreeNode;
namespace Ingen {
-class GraphObject;
+class GraphObjectImpl;
class Patch;
class Node;
class Port;
@@ -61,7 +61,7 @@ public:
private:
Path _path;
ObjectStore::Objects::iterator _store_iterator;
- Table<Path,GraphObject*> _removed_table;
+ Table<Path,GraphObjectImpl*> _removed_table;
Node* _node; ///< Same as _object if it is a Node, otherwise NULL
Port* _port; ///< Same as _object if it is a Port, otherwise NULL
DriverPort* _driver_port;
diff --git a/src/libs/engine/events/RenameEvent.cpp b/src/libs/engine/events/RenameEvent.cpp
index 9e5ef543..c643e456 100644
--- a/src/libs/engine/events/RenameEvent.cpp
+++ b/src/libs/engine/events/RenameEvent.cpp
@@ -23,7 +23,6 @@
#include "Patch.hpp"
#include "RenameEvent.hpp"
#include "Responder.hpp"
-#include "Tree.hpp"
#include "AudioDriver.hpp"
#include "MidiDriver.hpp"
@@ -78,10 +77,10 @@ RenameEvent::pre_process()
return;
}
- Table<Path,GraphObject*> removed = _engine.object_store()->remove(_store_iterator);
+ Table<Path,GraphObjectImpl*> removed = _engine.object_store()->remove(_store_iterator);
assert(removed.size() > 0);
- for (Table<Path,GraphObject*>::iterator i = removed.begin(); i != removed.end(); ++i) {
+ for (Table<Path,GraphObjectImpl*>::iterator i = removed.begin(); i != removed.end(); ++i) {
const Path& child_old_path = i->first;
assert(Path::descendant_comparator(_old_path, child_old_path));
diff --git a/src/libs/engine/events/RequestMetadataEvent.cpp b/src/libs/engine/events/RequestMetadataEvent.cpp
index fdd0ded3..0567d94d 100644
--- a/src/libs/engine/events/RequestMetadataEvent.cpp
+++ b/src/libs/engine/events/RequestMetadataEvent.cpp
@@ -19,7 +19,7 @@
#include <string>
#include "Responder.hpp"
#include "Engine.hpp"
-#include "GraphObject.hpp"
+#include "GraphObjectImpl.hpp"
#include "ObjectStore.hpp"
#include "interface/ClientInterface.hpp"
#include "ClientBroadcaster.hpp"
diff --git a/src/libs/engine/events/RequestMetadataEvent.hpp b/src/libs/engine/events/RequestMetadataEvent.hpp
index 714b1ec3..bbc2c871 100644
--- a/src/libs/engine/events/RequestMetadataEvent.hpp
+++ b/src/libs/engine/events/RequestMetadataEvent.hpp
@@ -25,7 +25,7 @@ using std::string;
namespace Ingen {
-class GraphObject;
+class GraphObjectImpl;
namespace Shared {
class ClientInterface;
} using Shared::ClientInterface;
@@ -47,7 +47,7 @@ private:
string _path;
string _key;
Raul::Atom _value;
- GraphObject* _object;
+ GraphObjectImpl* _object;
};
diff --git a/src/libs/engine/events/RequestObjectEvent.hpp b/src/libs/engine/events/RequestObjectEvent.hpp
index 263ea627..52459ada 100644
--- a/src/libs/engine/events/RequestObjectEvent.hpp
+++ b/src/libs/engine/events/RequestObjectEvent.hpp
@@ -26,7 +26,7 @@ using std::string;
namespace Ingen {
-class GraphObject;
+class GraphObjectImpl;
namespace Shared { class ClientInterface; }
using Shared::ClientInterface;
@@ -45,8 +45,8 @@ public:
void post_process();
private:
- string _path;
- GraphObject* _object;
+ const string _path;
+ GraphObjectImpl* _object;
};
diff --git a/src/libs/engine/events/SetMetadataEvent.cpp b/src/libs/engine/events/SetMetadataEvent.cpp
index 8e9163f0..ee0a62dc 100644
--- a/src/libs/engine/events/SetMetadataEvent.cpp
+++ b/src/libs/engine/events/SetMetadataEvent.cpp
@@ -20,7 +20,7 @@
#include "Responder.hpp"
#include "Engine.hpp"
#include "ClientBroadcaster.hpp"
-#include "GraphObject.hpp"
+#include "GraphObjectImpl.hpp"
#include "ObjectStore.hpp"
using std::string;
diff --git a/src/libs/engine/events/SetPolyphonicEvent.hpp b/src/libs/engine/events/SetPolyphonicEvent.hpp
index 4d0084c9..5922d443 100644
--- a/src/libs/engine/events/SetPolyphonicEvent.hpp
+++ b/src/libs/engine/events/SetPolyphonicEvent.hpp
@@ -26,7 +26,7 @@ using std::string;
namespace Ingen {
-class GraphObject;
+class GraphObjectImpl;
/** Delete all nodes from a patch.
@@ -43,9 +43,9 @@ public:
void post_process();
private:
- string _path;
- GraphObject* _object;
- bool _poly;
+ const string _path;
+ GraphObjectImpl* _object;
+ bool _poly;
};
diff --git a/src/libs/engine/events/RenameEvent.hpp b/src/libs/engine/events/RenameEvent.hpp
index ec3a0cec..e01f4409 100644
--- a/src/libs/engine/events/RenameEvent.hpp
+++ b/src/libs/engine/events/RenameEvent.hpp
@@ -30,7 +30,7 @@ template<typename T> class ListNode;
namespace Ingen {
-class GraphObject;
+class GraphObjectImpl;
class Patch;
class Node;
class Plugin;
@@ -38,7 +38,7 @@ class DisconnectNodeEvent;
class DisconnectPortEvent;
/** An event to change the name of an GraphObject.
*
* \ingroup engine
*/
@@ -38,7 +38,7 @@ class DisconnectNodeEvent;
class DisconnectPortEvent;
-/** An event to change the name of an GraphObject.
+/** An event to change the name of an GraphObjectImpl.
*
* \ingroup engine
diff --git a/src/libs/engine/events/SetMetadataEvent.hpp b/src/libs/engine/events/SetMetadataEvent.hpp
index 363a63eb..e65763c4 100644
--- a/src/libs/engine/events/SetMetadataEvent.hpp
+++ b/src/libs/engine/events/SetMetadataEvent.hpp
@@ -26,10 +26,10 @@ using std::string;
namespace Ingen {
-class GraphObject;
+class GraphObjectImpl;
-/** An event to set a piece of metadata for an GraphObject.
+/** An event to set a piece of metadata for an GraphObjectImpl.
*
* \ingroup engine
*/
@@ -46,7 +46,7 @@ private:
string _path;
string _key;
Raul::Atom _value;
- GraphObject* _object;
+ GraphObjectImpl* _object;
};